package com.example.springdemo.service;

import com.example.springdemo.dao.MerchantsPasswordRepository;
import com.example.springdemo.dao.MerchantsRepository;
import com.example.springdemo.entities.Merchants;
import com.example.springdemo.entities.password.MerchantsPassword;
import jakarta.annotation.Resource;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.util.List;

@Service
public class MerchantsServiceImpl implements MerchantsService {
    @Resource
    private MerchantsRepository merchantsRepository;
    @Resource
    private MerchantsPasswordRepository merchantsPasswordRepository;

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //添加商户时添加密码
    public Merchants addMerchants(Merchants merchant, MerchantsPassword merchantsPassword) {
        Merchants m = merchantsRepository.save(merchant);
        merchantsPasswordRepository.save(merchantsPassword);
        return m;
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //删除商户时删除密码
    public void deleteMerchantsById(Long merchantID) {
        merchantsRepository.deleteById(merchantID);
        merchantsPasswordRepository.deletePasswordById(merchantID);
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    public Merchants updateMerchants(Merchants merchant) {
        return merchantsRepository.save(merchant);
    }

    @Override
    public List<Merchants> findAllMerchants() {
        return merchantsRepository.findAll();
    }

    @Override
    public Merchants findById(Long id) {
        return merchantsRepository.findById(id).orElse(null);
    }

    @Override
    public Merchants findByName(String name) {
        return merchantsRepository.findByName(name);
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //修改密码
    public void updatePassword(String password, Long merchantID) {
        merchantsPasswordRepository.updatePassword(password, merchantID);
    }
}
