package com.example.springdemo.service;

import com.example.springdemo.dao.UsersPasswordRepository;
import com.example.springdemo.dao.UsersRepository;
import com.example.springdemo.entities.Users;
import com.example.springdemo.entities.password.UsersPassword;
import jakarta.annotation.Resource;
import org.springframework.data.jpa.repository.Modifying;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

@Service
public class UsersServiceImpl implements UsersService {
    @Resource
    private UsersRepository usersRepository;

    @Resource
    private UsersPasswordRepository usersPasswordRepository;

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //添加用户时同步添加密码
    public Users addUsers(Users user, UsersPassword usersPassword) {
        Users u = usersRepository.save(user);
        usersPasswordRepository.save(usersPassword);
        return u;
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //删除用户时同步删除密码
    public void deleteUsersById(Long userID) {
        usersRepository.deleteById(userID);
        usersPasswordRepository.deletePasswordById(userID);
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //删除用户时同步删除密码
    public void deleteUsersByName(String name) {
        usersRepository.deleteByName(name);
        //获取用户ID
        Long userID = usersRepository.findByName(name).getId();
        usersPasswordRepository.deletePasswordById(userID);
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    public Users updateUsers(Users user) {
        return usersRepository.save(user);
    }

    @Override
    public Iterable<Users> findAllUsers() {
        return usersRepository.findAll();
    }

    @Override
    public Users findById(Long userID) {
        return usersRepository.findById(userID).orElse(null);
    }

    @Override
    public Users findByName(String name) {
        return usersRepository.findByName(name);
    }

    @Override
    @Modifying
    @Transactional(rollbackFor = Exception.class)
    //更新用户密码
    public void updatePassword(String password, Long userID) {
        usersPasswordRepository.updatePassword(password, userID);
    }
}
